@@ -24,7 +24,7 @@ public class GetSystemProperty {
   public static void main(String args[]) {
     if( args.length == 0 ) {
       Properties p = System.getProperties();
-      Enumeration keys = p.keys();
+      Enumeration<Object> keys = p.keys();
       while (keys.hasMoreElements()) {
         String key = (String)keys.nextElement();
         String value = (String)p.get(key);
