@@ -36,10 +36,8 @@
 #ifdef GDCM_HAVE_WINSOCK_H
 #include <winsock.h>
 #endif
-#include <stdio.h> // snprintf
-#if defined(GDCM_HAVE_SNPRINTF)
-// ok nothing to do
-#elif defined(GDCM_HAVE__SNPRINTF)
+#include <cstdio> // snprintf
+#if defined(_MSC_VER) && (_MSC_VER < 1900)
 #define snprintf _snprintf
 #endif
 #ifdef GDCM_USE_COREFOUNDATION_LIBRARY
@@ -65,7 +63,6 @@
 
 // TODO: WIN32 replacement for C99 stuff:
 // #if defined(_WIN32) || defined(_WIN64)
-// #define snprintf _snprintf
 // #define vsnprintf _vsnprintf
 // #define strcasecmp _stricmp
 // #define strncasecmp _strnicmp
@@ -158,8 +155,8 @@ bool System::MakeDirectory(const char *path)
   bool ok = true;
   while(ok && (pos = dir.find('/', pos)) != std::string::npos)
     {
-    topdir = dir.substr(0, pos);
-    ok = ok && Mkdir(topdir.c_str());
+    topdir = dir.substr(0, pos+1);
+    ok = ok && (System::FileIsDirectory(topdir.c_str()) || 0 == Mkdir(topdir.c_str()));
     pos++;
     }
   if( !ok ) return false;
@@ -460,7 +457,7 @@ const char *System::GetCurrentProcessFileName()
 #else
   gdcmErrorMacro( "missing implementation" );
 #endif
-   return 0;
+   return nullptr;
 }
 
 #ifdef __USE_GNU
@@ -485,7 +482,7 @@ const char *System::GetCurrentModuleFileName()
   return System::GetCurrentProcessFileName();
 #endif
 
-  return 0;
+  return nullptr;
 }
 
 const char *System::GetCurrentResourcesDirectory()
@@ -494,7 +491,7 @@ const char *System::GetCurrentResourcesDirectory()
   static char path[PATH_MAX];
   Boolean success = false;
   CFURLRef pathURL = CFBundleCopyResourcesDirectoryURL(CFBundleGetMainBundle());
-  if (pathURL != NULL)
+  if (pathURL != nullptr)
     {
     success = CFURLGetFileSystemRepresentation(pathURL, true /*resolveAgainstBase*/, (unsigned char*) path, PATH_MAX);
     CFRelease(pathURL);
@@ -506,7 +503,7 @@ const char *System::GetCurrentResourcesDirectory()
     }
 #endif
   // Is there such beast on *any* other system but APPLE ?
-  return 0;
+  return nullptr;
 }
 
 /**
@@ -725,7 +722,7 @@ const char *System::GetTimezoneOffsetFromUTC()
 {
   static std::string buffer;
   char outstr[10];
-  time_t t = time(NULL);
+  time_t t = time(nullptr);
   struct tm *tmp = localtime(&t);
   size_t l = strftime(outstr, sizeof(outstr), "%z", tmp);
   assert( l == 5 ); (void)l;
@@ -812,7 +809,7 @@ bool System::GetCurrentDateTime(char date[22])
   // Apparently suseconds_t is defined as long on linux system... why would this be signed ?
 
   struct timeval tv;
-  gettimeofday (&tv, NULL);
+  gettimeofday (&tv, nullptr);
   timep = tv.tv_sec;
   // A concatenated date-time character string in the format:
   // YYYYMMDDHHMMSS.FFFFFF&ZZXX
@@ -906,7 +903,7 @@ char *System::StrTokR(char *str, const char *delim, char **nextp)
   // PD -> http://groups.google.com/group/comp.lang.c/msg/7c7b39328fefab9c
   char *ret;
 
-  if (str == NULL)
+  if (str == nullptr)
     {
     str = *nextp;
     }
@@ -915,7 +912,7 @@ char *System::StrTokR(char *str, const char *delim, char **nextp)
 
   if (*str == '\0')
     {
-    return NULL;
+    return nullptr;
     }
 
   ret = str;
@@ -941,7 +938,7 @@ char *System::StrSep(char **sp, const char *sep)
   // http://stackoverflow.com/questions/8512958/is-there-a-windows-variant-of-strsep
 #if 1
   char *p, *s;
-  if (sp == NULL || *sp == NULL || **sp == '\0') return NULL;
+  if (sp == nullptr || *sp == nullptr || **sp == '\0') return nullptr;
   s = *sp;
   p = s + strcspn(s, sep);
   if (*p != '\0') *p++ = '\0';
@@ -984,7 +981,7 @@ static const char *CharsetAliasToName(const char *alias)
 
 const char *System::GetLocaleCharset()
 {
-  const char *codeset = NULL;
+  const char *codeset = nullptr;
 #if defined(GDCM_HAVE_NL_LANGINFO)
   //setlocale (LC_CTYPE, NULL);
   /* According to documentation nl_langinfo needs :
