@@ -59,13 +59,13 @@ basic_zip_streambuf<charT, traits>::basic_zip_streambuf(ostream_reference ostrea
       _buffer(buffer_size, 0),
       _crc(0)
 {
-    _zip_stream.zalloc = (alloc_func) 0;
-    _zip_stream.zfree = (free_func) 0;
+    _zip_stream.zalloc = (alloc_func) nullptr;
+    _zip_stream.zfree = (free_func) nullptr;
 
-    _zip_stream.next_in = NULL;
+    _zip_stream.next_in = nullptr;
     _zip_stream.avail_in = 0;
     _zip_stream.avail_out = 0;
-    _zip_stream.next_out = NULL;
+    _zip_stream.next_out = nullptr;
 
     if(level > 9)
         level = 9;
@@ -315,13 +315,13 @@ basic_unzip_streambuf<charT, traits>::basic_unzip_streambuf(istream_reference is
       _crc(0)
 {
     // setting zalloc, zfree and opaque
-    _zip_stream.zalloc = (alloc_func) 0;
-    _zip_stream.zfree = (free_func) 0;
+    _zip_stream.zalloc = (alloc_func) nullptr;
+    _zip_stream.zfree = (free_func) nullptr;
 
-    _zip_stream.next_in = NULL;
+    _zip_stream.next_in = nullptr;
     _zip_stream.avail_in = 0;
     _zip_stream.avail_out = 0;
-    _zip_stream.next_out = NULL;
+    _zip_stream.next_out = nullptr;
 
     _err = inflateInit2(&_zip_stream, window_size);
 
@@ -508,7 +508,7 @@ basic_unzip_streambuf<charT, traits>::fill_input_buffer(void)
       if( _istream.eof() )
         {
         // Ok so we reached the end of file, since we did not read no header
-        // we have to explicitely tell zlib the compress stream ends, therefore
+        // we have to explicitly tell zlib the compress stream ends, therefore
         // we add an extra \0 character...it may not always be needed...
         assert( nbytesread < (std::streamsize)(_input_buffer.size() / sizeof(char_type)) );
         _input_buffer[ (unsigned int)nbytesread ] = 0;
@@ -533,6 +533,11 @@ basic_unzip_streambuf<charT, traits>::fill_input_buffer(void)
 // PUBLIC
 //-----------------------------------------------------------------------------
 
+#if defined(_MSC_VER)
+# pragma warning (push)
+# pragma warning (disable:4355)
+#endif
+
 /**
  */
 template <class charT, class traits> inline
@@ -553,6 +558,10 @@ basic_zip_ostream<charT, traits>::basic_zip_ostream(ostream_reference ostream,
         add_header();
 }
 
+#if defined(_MSC_VER)
+# pragma warning (pop)
+#endif
+
 /** Destructor
  */
 template <class charT, class traits>
@@ -658,6 +667,11 @@ basic_zip_ostream<charT,traits>& basic_zip_ostream<charT, traits>::add_footer(vo
 // PUBLIC
 //-----------------------------------------------------------------------------
 
+#if defined(_MSC_VER)
+# pragma warning (push)
+# pragma warning (disable:4355)
+#endif
+
 /** Constructor
  */
 template <class charT, class traits>
@@ -679,6 +693,10 @@ basic_zip_istream<charT, traits>::basic_zip_istream(istream_reference istream,
     }
 }
 
+#if defined(_MSC_VER)
+# pragma warning (pop)
+#endif
+
 /** returns true if it is a gzip file
  */
 template <class charT, class traits> inline
