@@ -87,8 +87,7 @@ static Tag BasicApplicationLevelConfidentialityProfileAttributes[] = {
 
 
 Anonymizer::~Anonymizer()
-{
-}
+= default;
 
 bool Anonymizer::Empty( Tag const &t)
 {
@@ -466,7 +465,7 @@ bool Anonymizer::CheckIfSequenceContainsAttributeToAnonymize(File const &file, S
       {
       const DataElement &de = *it;
       VR vr = DataSetHelper::ComputeVR(file, nested, de.GetTag() );
-      SmartPointer<SequenceOfItems> sqi2 = 0;
+      SmartPointer<SequenceOfItems> sqi2 = nullptr;
       if( vr == VR::SQ )
         {
         sqi2 = de.GetValueAsSQ();
@@ -558,7 +557,7 @@ bool Anonymizer::BasicApplicationLevelConfidentialityProfile1()
     {
     const DataElement &de = *it;
     //const SequenceOfItems *sqi = de.GetSequenceOfItems();
-    SmartPointer<SequenceOfItems> sqi = 0;
+    SmartPointer<SequenceOfItems> sqi = nullptr;
     VR vr = DataSetHelper::ComputeVR(*F, ds, de.GetTag() );
     if( vr == VR::SQ )
       {
@@ -744,7 +743,7 @@ catch(...)
 }
 
 
-bool IsVRUI(Tag const &tag)
+static bool IsVRUI(Tag const &tag)
 {
   static const Global &g = Global::GetInstance();
   static const Dicts &dicts = g.GetDicts();
@@ -945,7 +944,7 @@ void Anonymizer::RecurseDataSet( DataSet & ds )
     DataElement de = *it; ++it;
     //const SequenceOfItems *sqi = de.GetSequenceOfItems();
     VR vr = DataSetHelper::ComputeVR(*F, ds, de.GetTag() );
-    SmartPointer<SequenceOfItems> sqi = 0;
+    SmartPointer<SequenceOfItems> sqi = nullptr;
     if( vr == VR::SQ )
       {
       sqi = de.GetValueAsSQ();
