@@ -83,7 +83,7 @@ VR DataSetHelper::ComputeVR(File const &file, DataSet const &ds, const Tag& tag)
   //const Dict &d = dicts.GetPublicDict();
 
   std::string strowner;
-  const char *owner = 0;
+  const char *owner = nullptr;
   const Tag& t = tag;
   if( t.IsPrivate() && !t.IsPrivateCreator() )
     {
@@ -97,6 +97,22 @@ VR DataSetHelper::ComputeVR(File const &file, DataSet const &ds, const Tag& tag)
   // not much we can do...
   if( refvr == VR::INVALID || refvr == VR::UN )
     {
+    // New public/private tag, let's forward what is found in the file (hopefully correct)
+    if( ds.FindDataElement( t ) )
+      {
+      const DataElement &de = ds.GetDataElement( t );
+      const VR &devr = de.GetVR();
+      if( devr != VR::INVALID && devr != VR::UN )
+        {
+        gdcmWarningMacro("Please report. Missing dict entry for: " << de );
+        return devr;
+        }
+      // CP-246
+      if( devr == VR::UN && de.IsUndefinedLength() )
+        {
+        return VR::SQ;
+        }
+      }
     // postcondition says it cannot be VR::INVALID, so return VR::UN
     return VR::UN;
     }
@@ -191,6 +207,12 @@ VR DataSetHelper::ComputeVR(File const &file, DataSet const &ds, const Tag& tag)
     if( pixeldata == t || t.IsGroupXX(overlaydata) )
       {
       vr = VR::OW;
+      if( ds.FindDataElement( t ) )
+        {
+        const DataElement &de = ds.GetDataElement( t );
+        const gdcm::SequenceOfFragments * sqf = de.GetSequenceOfFragments();
+        if( sqf ) vr = VR::OB;
+        }
       }
     else if( waveformdata == t || waveformpaddingvalue == t )
       {
@@ -215,11 +237,31 @@ VR DataSetHelper::ComputeVR(File const &file, DataSet const &ds, const Tag& tag)
       }
     else
       {
-      assert( 0 && "Should not happen" );
-      vr = VR::INVALID;
+      // We may reach here coming from a private attribute
+      if( t.IsPrivate() && !t.IsPrivateCreator() )
+        {
+        // ?HitachiMedical.Dream.Cabinet.ApplicationObjects.ImageAppData?
+        vr = VR::UN;
+        // no clue which VR to pick, try to re-use the one from the file:
+        if( ds.FindDataElement( t ) )
+          {
+          const DataElement &de = ds.GetDataElement( t );
+          const VR &devr = de.GetVR();
+          if( devr != VR::INVALID && devr != VR::UN )
+            {
+            gdcmWarningMacro("Possibly incorrect VR for: " << de );
+            vr = devr;
+            }
+          }
+        }
+      else
+        {
+        // Do we need to update this logic ?
+        gdcmAssertAlwaysMacro( 0 && "Should not happen" );
+        }
       }
     }
-  else if( vr == VR::US_SS_OW )
+  else if( vr == VR::US_SS_OW || vr == VR::US_OW )
     {
     vr = VR::OW;
     }
