@@ -14,6 +14,7 @@
 #include "gdcmImageCodec.h"
 #include "gdcmJPEGCodec.h"
 #include "gdcmByteSwap.txx"
+#include "gdcmImageChangePhotometricInterpretation.h"
 #include "gdcmTrace.h"
 
 #include <iostream>
@@ -47,8 +48,7 @@ ImageCodec::ImageCodec()
 }
 
 ImageCodec::~ImageCodec()
-{
-}
+= default;
 
 bool ImageCodec::GetHeaderInfo(std::istream &, TransferSyntax &)
 {
@@ -113,7 +113,7 @@ bool ImageCodec::DoByteSwap(std::istream &is, std::ostream &os)
   if( PF.GetBitsAllocated() == 16 )
     {
     ByteSwap<uint16_t>::SwapRangeFromSwapCodeIntoSystem((uint16_t*)
-      dummy_buffer, SwapCode::LittleEndian, buf_size/2);
+      (void*)dummy_buffer, SwapCode::LittleEndian, buf_size/2);
     }
 #else
   // GE_DLX-8-MONO2-PrivateSyntax.dcm is 8bits
@@ -121,7 +121,7 @@ bool ImageCodec::DoByteSwap(std::istream &is, std::ostream &os)
   if ( PF.GetBitsAllocated() == 16 )
     {
     ByteSwap<uint16_t>::SwapRangeFromSwapCodeIntoSystem((uint16_t*)
-      dummy_buffer, SwapCode::BigEndian, buf_size/2);
+      (void*)dummy_buffer, SwapCode::BigEndian, buf_size/2);
     }
 #endif
   os.write(dummy_buffer, buf_size);
@@ -191,6 +191,63 @@ assert(0); // Do not use this code !
   return true;
 }
 
+bool ImageCodec::DoYBRFull422(std::istream &is, std::ostream &os)
+{
+  // FIXME: Do some stupid work:
+  std::streampos start = is.tellg();
+  assert( 0 - start == 0 );
+  is.seekg( 0, std::ios::end);
+  const size_t buf_size = (size_t)is.tellg();
+  const size_t rgb_buf_size = buf_size * 3 / 2;
+  unsigned char *dummy_buffer = new unsigned char[buf_size];
+  is.seekg(start, std::ios::beg);
+  is.read( (char*)dummy_buffer, buf_size);
+  is.seekg(start, std::ios::beg); // reset
+
+  assert( !(rgb_buf_size % 3) );
+  assert( !(buf_size % 2) );
+  unsigned char *copy = new unsigned char[ rgb_buf_size ];
+  const size_t size = buf_size/4;
+
+  for (size_t j = 0; j < size; ++j)
+    {
+    unsigned char ybr422[4];
+    ybr422[0] = dummy_buffer[4*j+0];
+    ybr422[1] = dummy_buffer[4*j+1];
+    ybr422[2] = dummy_buffer[4*j+2];
+    ybr422[3] = dummy_buffer[4*j+3];
+
+#if 0
+    unsigned char ybr1[3];
+    unsigned char ybr2[3];
+    ybr1[0] = ybr422[0];
+    ybr1[1] = ybr422[2];
+    ybr1[2] = ybr422[3];
+    ybr2[0] = ybr422[1];
+    ybr2[1] = ybr422[2];
+    ybr2[2] = ybr422[3];
+
+    unsigned char rgb[6];
+    ImageChangePhotometricInterpretation::YBR2RGB(rgb + 0, ybr1);
+    ImageChangePhotometricInterpretation::YBR2RGB(rgb + 3, ybr2);
+    memcpy(copy + 6 * j, rgb, 6 );
+#else
+    unsigned char ybr[6]; // ybr1 + ybr2
+    ybr[0] = ybr422[0];
+    ybr[1] = ybr422[2];
+    ybr[2] = ybr422[3];
+    ybr[3] = ybr422[1];
+    ybr[4] = ybr422[2];
+    ybr[5] = ybr422[3];
+    memcpy(copy + 6 * j, ybr, 6 );
+#endif
+    }
+  os.write((char*)copy, rgb_buf_size);
+  delete[] copy;
+  delete[] dummy_buffer;
+  return true;
+}
+
 bool ImageCodec::DoPlanarConfiguration(std::istream &is, std::ostream &os)
 {
   // FIXME: Do some stupid work:
@@ -386,9 +443,10 @@ struct ApplyMask
   uint16_t pmask;
 };
 
-bool ImageCodec::CleanupUnusedBits(char * data, size_t datalen)
+bool ImageCodec::CleanupUnusedBits(char * data8, size_t datalen)
 {
   if( !NeedOverlayCleanup ) return true;
+  void * data = data8;
   assert( PF.GetBitsAllocated() > 8 );
   if( PF.GetBitsAllocated() == 16 )
     {
@@ -480,14 +538,22 @@ bool ImageCodec::DoOverlayCleanup(std::istream &is, std::ostream &os)
     else // Pixel are unsigned
       {
 #if 1
-      uint16_t c;
-      while( is.read((char*)&c,2) )
+      // On Windows, is.read and os.write are expensive operations.
+      // If we called it for each value then conversion would be extremely slow.
+      // Therefore we read/mask/write 1000 values at once.
+      const unsigned int bufferSize = 1000;
+      std::vector<uint16_t> buffer(bufferSize);
+      while (is)
         {
-        c = (uint16_t)(
-          (c >> (PF.GetBitsStored() - PF.GetHighBit() - 1)) & pmask);
-        os.write((char*)&c, 2 );
-        }
-      //os.rdbuf( is.rdbuf() );
+        is.read((char *)&buffer[0], bufferSize * sizeof(uint16_t));
+        std::streamsize bytesRead = is.gcount();
+        std::vector<uint16_t>::iterator validBufferEnd = buffer.begin() + bytesRead / sizeof(uint16_t);
+        for (std::vector<uint16_t>::iterator it = buffer.begin(); it != validBufferEnd; ++it)
+          {
+          *it = ((*it >> (PF.GetBitsStored() - PF.GetHighBit() - 1)) & pmask);
+          }
+        os.write((char *)&buffer[0], bytesRead);
+        };
 #else
       //std::ostreambuf_iterator<char> end_of_stream_iterator;
       //std::ostreambuf_iterator<char> out_iter(os.rdbuf());
@@ -585,8 +651,10 @@ bool ImageCodec::DecodeByStreams(std::istream &is, std::ostream &os)
       const JPEGCodec *c = dynamic_cast<const JPEGCodec*>(this);
       if( !c )
         {
-        gdcmErrorMacro( "YBR_FULL_422 is not implemented in GDCM. Image will be displayed incorrectly" );
+        //gdcmErrorMacro( "YBR_FULL_422 is not implemented in GDCM. Image will be displayed incorrectly" );
         //this->SetPhotometricInterpretation( PhotometricInterpretation::RGB );
+        DoYBRFull422(*cur_is,pl_os);
+        cur_is = &pl_os;
         }
       }
     break;
