@@ -29,7 +29,7 @@ namespace gdcm
 
 JPEGCodec::JPEGCodec():BitSample(0)/*,Lossless(true)*/,Quality(100)
 {
-  Internal = NULL;
+  Internal = nullptr;
 }
 
 JPEGCodec::~JPEGCodec()
@@ -100,7 +100,7 @@ void JPEGCodec::SetPixelFormat(PixelFormat const &pt)
 void JPEGCodec::SetupJPEGBitCodec(int bit)
 {
   BitSample = bit;
-  delete Internal; Internal = NULL;
+  delete Internal; Internal = nullptr;
   assert( Internal == NULL );
   // what should I do with those single bit images ?
   if ( BitSample <= 8 )
@@ -124,7 +124,7 @@ void JPEGCodec::SetupJPEGBitCodec(int bit)
     gdcmWarningMacro( "Cannot instantiate JPEG codec for bit sample: " << bit );
     // Clearly make sure Internal will not be used
     delete Internal;
-    Internal = NULL;
+    Internal = nullptr;
     }
 }
 
