@@ -253,7 +253,10 @@ static const char * const gdcmMediaStorageDataFiles[][2] = {
 { "EmptyIcon_Bug417.dcm" , "1.2.840.10008.5.1.4.1.1.2" },
 { "EnhancedWithIPPPerFrameIOPShared.dcm" , "1.2.840.10008.5.1.4.1.1.13.1.2" },
 { "FUJI-ffff-MONO1-J2K.dcm" , "1.2.840.10008.5.1.4.1.1.1" },
+{ "JPEGLosslessSeNonZero.dcm" , "1.2.840.10008.5.1.4.1.1.7" },
+{ "US-YBR_FULL_422-EVRLE.dcm" , "1.2.840.10008.5.1.4.1.1.6.1" },
+{ "PET-GE-dicomwrite-PixelDataSQUN.dcm" , "1.2.840.10008.5.1.4.1.1.128" },
 
 /* Stopping condition */
-{ 0 ,0 }
+{ nullptr ,nullptr }
 };
