@@ -231,6 +231,11 @@ static const StreamOffset gdcmSelectedPrivateGroupOffsetDataFiles[] = {
 { "JPEG_LS_InvalidEscapeSequence_COM_padding.dcm", 534 },
 { "LengthOfItemLarger.dcm", 1044 },
 { "GE_MR_0025xx1bProtocolDataBlockXML.dcm",1358},
+{ "EmptyIcon_Bug417.dcm",1000},
+{ "EnhancedWithIPPPerFrameIOPShared.dcm",772},
+{ "FUJI-ffff-MONO1-J2K.dcm",982},
+{ "JPEGLosslessSeNonZero.dcm",530},
+{ "US-YBR_FULL_422-EVRLE.dcm",744},
 { "dicomdir_With_embedded_icons",7125212 },
 { "dicomdir_Pms_WithVisit_WithPrivate_WithStudyComponents",37218 },
 { "dicomdir_Acusson_WithPrivate_WithSR",3826 },
@@ -240,5 +245,5 @@ static const StreamOffset gdcmSelectedPrivateGroupOffsetDataFiles[] = {
 { "DICOMDIR_MR_B_VA12A",14853880 },
 
 /* Stopping condition */
-{ 0 ,0 },
+{ nullptr ,0 },
 };
