@@ -19,35 +19,35 @@ int TestVM(int, char *[])
   //gdcm::VM::VMType vm = gdcm::LengthToVM<1>::TVM;
 
   const char str1[] = " 1\\2";
-  unsigned int count1 = gdcm::VM::GetNumberOfElementsFromArray(str1, (unsigned int)strlen(str1) );
+  const size_t count1 = gdcm::VM::GetNumberOfElementsFromArray(str1, (unsigned int)strlen(str1) );
   if( count1 != 2 ) return 1;
 
   const char str2[] = "  1\\2\\3";
-  unsigned int count2 = gdcm::VM::GetNumberOfElementsFromArray(str2, (unsigned int)strlen(str2) );
+  const size_t count2 = gdcm::VM::GetNumberOfElementsFromArray(str2, (unsigned int)strlen(str2) );
   if( count2 != 3 ) return 1;
 
   const char str3[] = "   1";
-  unsigned int count3 = gdcm::VM::GetNumberOfElementsFromArray(str3, (unsigned int)strlen(str3) );
+  const size_t count3 = gdcm::VM::GetNumberOfElementsFromArray(str3, (unsigned int)strlen(str3) );
   if( count3 != 1 ) return 1;
 
   const char str4[] = "";
-  unsigned int count4 = gdcm::VM::GetNumberOfElementsFromArray(str4, (unsigned int)strlen(str4) );
+  const size_t count4 = gdcm::VM::GetNumberOfElementsFromArray(str4, (unsigned int)strlen(str4) );
   if( count4 != 0 ) return 1;
 
-  const char *str5 = 0;
-  unsigned int count5 = gdcm::VM::GetNumberOfElementsFromArray(str5, 0);
+  const char *str5 = nullptr;
+  const size_t count5 = gdcm::VM::GetNumberOfElementsFromArray(str5, 0);
   if( count5 != 0 ) return 1;
 
   const char str6[] = "   1";
-  unsigned int count6 = gdcm::VM::GetNumberOfElementsFromArray(str6, (unsigned int)strlen(str6) );
+  const size_t count6 = gdcm::VM::GetNumberOfElementsFromArray(str6, (unsigned int)strlen(str6) );
   if( count6 != 1 ) return 1;
 
   const char str7[] = "   1 \\   2  ";
-  unsigned int count7 = gdcm::VM::GetNumberOfElementsFromArray(str7, (unsigned int)strlen(str7) );
+  const size_t count7 = gdcm::VM::GetNumberOfElementsFromArray(str7, (unsigned int)strlen(str7) );
   if( count7 != 2 ) return 1;
 
   const char str8[] = "   ";
-  unsigned int count8 = gdcm::VM::GetNumberOfElementsFromArray(str8, (unsigned int)strlen(str8) );
+  const size_t count8 = gdcm::VM::GetNumberOfElementsFromArray(str8, (unsigned int)strlen(str8) );
   if( count8 != 0 )
     {
     std::cerr << "count8 failed" << std::endl;
@@ -55,11 +55,11 @@ int TestVM(int, char *[])
     }
 
   const char str9[] = "     \\      ";
-  unsigned int count9 = gdcm::VM::GetNumberOfElementsFromArray(str9, (unsigned int)strlen(str9) );
+  const size_t count9 = gdcm::VM::GetNumberOfElementsFromArray(str9, (unsigned int)strlen(str9) );
   if( count9 != 0 ) return 1;
 
   const char str10[] = "   3  \\      ";
-  unsigned int count10 = gdcm::VM::GetNumberOfElementsFromArray(str10, (unsigned int)strlen(str10) );
+  const size_t count10 = gdcm::VM::GetNumberOfElementsFromArray(str10, (unsigned int)strlen(str10) );
   if( count10 != 1 ) return 1;
 
   // store invalid combinations inside an int array to trick the compiler
