@@ -132,6 +132,13 @@ int TestPixelFormat(int , char *[])
   pf3.SetHighBit( 8 );
   if( pf3.GetHighBit() != 7 ) return 1;
 
+  gdcm::PixelFormat pf4 = PixelFormat::UINT16;
+  pf4.SetBitsStored(8);
+  if( pf4.GetScalarType() != gdcm::PixelFormat::UINT16 ) return 1;
+  pf4.SetPixelRepresentation(1);
+  if( pf4.GetScalarType() != gdcm::PixelFormat::INT16 ) return 1;
+
+
   return 0;
 }
 
